@@ -61,11 +61,12 @@ class Eaves:
         self.thread_true = True
         self.handlers: dict = {}
         self.screen: Optional[Surface] = None
-        self.config_file: Optional[ConfigFile] = None
         self.current_status: str = 'main_menu'
         self.type_handlers = {
             str: lambda status: exec('self.current_status = status')
         }
+        self.res: Optional[tuple[int, int]] = None
+        self.config_file: Optional[ConfigFile] = None
         self._before_startup: Optional[Callable] = None
         self._before_shutdown: Optional[Callable] = None
         self.handlers_to_load: list[str] = []
@@ -101,7 +102,7 @@ class Eaves:
             if func_before_running:
                 ret = func.__annotations__['return']
                 def new_func(events) -> ret:
-                    return func(func_before_running(events))
+                    return func(func_before_running(events)) # type: ignore
 
                 self.handlers[name] = new_func
             else:
@@ -123,7 +124,7 @@ class Eaves:
         location: tuple[int, int] = (0, 0)
     ) -> None:
         source = font.render(text, antialias, color, background)
-        self.screen.blit(source, location)
+        self.screen.blit(source, location) # type: ignore
 
     def run(
         self, window_caption: str,
@@ -146,11 +147,11 @@ class Eaves:
 
         # set screen
         if not screen_size:
-            res = self.get_current_screen_size()
+            self.res = self.get_current_screen_size()
         else: 
-            res = screen_size
+            self.res = screen_size
         
-        self.screen = display.set_mode(res, window_type)
+        self.screen = display.set_mode(self.res, window_type)
         display.set_caption(window_caption)
 
         if self._before_startup:
